pub enum LineStatus {
Free,
Busy(Shared<Receiver<()>>),
}Available on crate feature
line_token only.Expand description
The current status of a line.
Variants
Free
The line is free.
Busy(Shared<Receiver<()>>)
The line is busy, and the nested future can be used to wait till the line becomes free again.