Token

Struct Token 

pub struct Token<'t> { /* private fields */ }
A token that symbolizes the current consumer holds exclusive access to the corresponding Line.

The Line is automatically released when this token goes out of scope and is dropped.