Line

Struct Line 

pub struct Line { /* private fields */ }
A Line from which a Token can be acquired.

Implementations

Source

impl Line

pub fn new() -> Line

Instantiates a new Line.

pub fn try_acquire_token<'l>(&'l self) -> AcquireOutcome<'l>

Attempts to acquire a Token for this line.

The Token automatically releases the line upon leaving the current scope and getting dropped.

If a Token has already been acquired for this line, a future to await is returned instead. It resolves when the current token holder has finished handling the current error and releases the line.